@@ -70,6 +70,7 @@ percentileMap <- function(data,
                           d.fig = 3.5,
                           static = FALSE,
                           static.nrow = NULL,
+                          progress = TRUE,
                           ...,
                           control = NULL) {
   # check basemap providers are valid
@@ -123,7 +124,7 @@ percentileMap <- function(data,
   }
 
   # cut data
-  data <- quick_cutdata(data = data, type = type)
+  data <- openair::cutData(x = data, type = type %||% "default", ...)
 
   # deal with popups
   if (length(popup) > 1) {
@@ -187,7 +188,8 @@ percentileMap <- function(data,
       split_col = split_col,
       d.fig = d.fig,
       popup = popup,
-      label = label
+      label = label,
+      progress = progress
     )
 
   if (static) {
