@@ -77,6 +77,7 @@ windroseMap <- function(data,
                         d.fig = 3.5,
                         static = FALSE,
                         static.nrow = NULL,
+                        progress = TRUE,
                         ...,
                         control = NULL) {
   # check basemap providers are valid
@@ -100,7 +101,7 @@ windroseMap <- function(data,
   data$ws_dup <- data$ws
 
   # cut data
-  data <- quick_cutdata(data = data, type = type)
+  data <- openair::cutData(x = data, type = type %||% "default", ...)
 
   # deal with popups
   if (length(popup) > 1) {
@@ -173,7 +174,8 @@ windroseMap <- function(data,
       split_col = split_col,
       d.fig = d.fig,
       popup = popup,
-      label = label
+      label = label,
+      progress = progress
     )
 
   if (static) {
